set echo on feedback on
create user auth identified by authpass temporary tablespace TEMP;
alter user auth default tablespace AUTH_DATA;
alter user auth quota unlimited on AUTH_DATA;
grant resource, create session to auth;
grant select any dictionary to auth;
grant SELECT_CATALOG_ROLE to auth;
grant execute on SYS.DBMS_SYSTEM to AUTH;

create table auth.auth_log (
  connection_date  date,
  log_id           number,
  username         varchar2(30),
  dba              varchar2(3),
  link             varchar2(3),
  osuser           varchar2(30),
  program          varchar2(48),
  module           varchar2(48),
  machine          varchar2(64),
  action           varchar2(7),
  condition        varchar2(1000),
  condition_eval   varchar2(800) ) tablespace AUTH_DATA;
  
create index auth.auth_log_connection_date_idx on auth.auth_log (connection_date) tablespace AUTH_DATA;  
create index auth.auth_log_log_id_idx on auth.auth_log (log_id) tablespace AUTH_DATA;

create sequence auth.auth_log_id_seq cache 20;

create table auth.auth_control (
  enabled          char         default 'Y' not null,
  condition        varchar2(1000) not null,
  permission_level number       default '1' not null,
  permission       varchar2(12) default 'UNAUTHORIZED' not null,
  action           varchar2(6)  not null,
  block_msg        varchar2(30) default 'Access Blocked',
  email_notice     varchar2(3)  default 'N' not null,
  expires          date, 
  description      varchar2(500) ) tablespace AUTH_DATA;

alter table auth.auth_control add constraint auth_control_enabled_ck check (enabled in ('Y','N'));
alter table auth.auth_control add constraint auth_control_permission_ck check (permission in ('AUTHORIZED','UNAUTHORIZED'));
alter table auth.auth_control add constraint auth_control_action_ck check (action in ('NONE','LOG','TRACE','RECORD','BLOCK'));
alter table auth.auth_control add constraint auth_control_email_notice_ck check (email_notice in ('Y','N','S'));

create table auth.auth_trace (
  log_id           number,
  logon_time       date,
  sid              number,
  spid             number,
  trace_path_file  varchar2(200),
  action	   varchar2(6),
  status           varchar2(15)) tablespace AUTH_DATA;

create index auth.auth_trace_log_id_idx on auth.auth_trace (log_id) tablespace AUTH_DATA;  
  
create table auth.auth_email (
  email_address varchar2(60) not null,
  enabled char default 'Y',
  limit varchar2(30)) tablespace AUTH_DATA;
alter table auth.auth_email add constraint auth_email_enabled_ck check (enabled in ('Y','N'));

--Configure a list of email addresses you'll want to use as defaults.
--insert into auth.auth_email (email_address,enabled) values ('my_email@company.com','Y');
commit;

create role auth_update;
revoke auth_update from djackson;
create role auth_readonly;
revoke auth_readonly from djackson;
grant select on auth.AUTH_CONTROL to auth_readonly;
grant select on auth.AUTH_EMAIL   to auth_readonly;
grant select on auth.AUTH_LOG     to auth_readonly;
grant select on auth.AUTH_TRACE   to auth_readonly;
grant select,insert,update,delete on auth.AUTH_CONTROL to auth_update;
grant select,insert,update,delete on auth.AUTH_EMAIL   to auth_update;
grant select,insert,update,delete on auth.AUTH_LOG     to auth_update;
grant select,insert,update,delete on auth.AUTH_TRACE   to auth_update;

create user auth_update_user identified by carefree;
alter user auth_update_user temporary tablespace temp;
alter user auth_update_user default tablespace users;
grant create session to auth_update_user;
grant auth_update to auth_update_user;

create user auth_readonly_user identified by noworry;
alter user auth_readonly_user temporary tablespace temp;
alter user auth_readonly_user default tablespace users;
grant create session to auth_readonly_user;
grant auth_readonly to auth_readonly_user;

CREATE OR REPLACE  PROCEDURE auth.auth_sendmail( 
  sender in varchar2,
  recipient varchar2, 
  subj in varchar2, 
  body in varchar2,
  cc_recipient in varchar2 ) 
IS
  connection UTL_SMTP.connection ; 
  v_reply UTL_SMTP.REPLY ; 
  message VARCHAR2(32767) ; 
  crlf VARCHAR2(2):=chr(13)||chr(10); 
BEGIN 
  connection := UTL_SMTP.open_connection('localhost',25) ; 
  v_reply := UTL_SMTP.HELO(Connection,'localhost') ; 
  v_reply := UTL_SMTP.MAIL(Connection,sender) ; 
  v_reply := UTL_SMTP.rcpt(Connection,recipient) ; 

  IF cc_recipient is not null then 
    UTL_SMTP.rcpt(connection,cc_recipient); 
  END IF; 

  Message :='Date: '||to_char(sysdate,'DD-MON-YYYY HH:MI PM')||crlf|| 
    'From: '||sender||crlf|| 
    'To: '||recipient||crlf|| 
    'Cc: '||cc_recipient||crlf|| 
    'Subject: '||subj||crlf|| 
    ''||crlf|| 
    body; 

  UTL_SMTP.DATA(Connection,'MIME-Version: 1.0' ||crlf||'Content-type: text' || crlf||Message); 
  UTL_SMTP.QUIT(Connection); 

END auth_SENDMAIL; 
/

CREATE OR REPLACE  PROCEDURE AUTH.AUTH_TRACE_OFF 
  (p_sid in varchar)
AS
  v_serial                      number;
BEGIN
  -- Get the Serial#
  select s.serial# into v_serial
    from v$session s where s.sid = p_sid;
  -- Turn Tracing Off
  sys.dbms_system.set_ev(p_sid,v_serial,10046,0,'');
  -- Insert into Trace table
  update auth.auth_trace set status = 'READY' where status = 'IN-PROGRESS' and sid = p_sid;
  commit;
END;
/

CREATE OR REPLACE  PROCEDURE "AUTH"."AUTH_TRACE_ON" 
  (p_sid in varchar)
AS
  v_instance_name               varchar2(16);
  v_host_name                   varchar2(64);
  v_username                    varchar2(30);
  v_osuser                      varchar2(30);
  v_program                     varchar2(48);
  v_module                      varchar2(48);
  v_machine                     varchar2(64);
  v_spid                        number;
  v_logon_time                  date;
  v_serial                      number;
  v_trace_path_file             varchar2(200);
  v_log_id                      number;
BEGIN
  -- Get Instance and Host names
  select instance_name, host_name into v_instance_name, v_host_name from v$instance;
  -- Get the System Process ID
  select s. username, s.osuser, s.program, s.module, s.machine, p.spid, s.logon_time, s.serial#
    into v_username, v_osuser, v_program, v_module, v_machine, v_spid, v_logon_time, v_serial
    from v$session s, v$process p where s.paddr = p.addr and s.sid = p_sid;
  -- Get trace file path and name
  select value||'/'||lower(v_instance_name)||'_ora_'||v_spid||'.trc' into v_trace_path_file
    from v$parameter where name = 'user_dump_dest';
  -- Get Log id
  select auth.auth_log_id_seq.nextval into v_log_id from dual;
  -- Turn Tracing On
  -- sys.dbms_system.set_sql_trace_in_session(p_sid,v_serial,true);
  sys.dbms_system.set_ev(p_sid,v_serial,10046,12,'');
  -- Insert into Log table
  insert into auth.auth_log
    (connection_date, log_id, username, dba, link, osuser, program, module, machine, action, condition, condition_eval)
  values (sysdate, v_log_id, v_username, null, null, v_osuser, v_program, v_module, v_machine, 'TRACE', 'MANUAL TRACE', null );
  commit;
  -- Insert into Trace table
  insert into auth.auth_trace (log_id, logon_time, sid, spid, trace_path_file, action, status)
    values (v_log_id, v_logon_time, p_sid, v_spid, v_trace_path_file,  'TRACE' ,'IN-PROGRESS');
  commit;
END;
/

@auth_connection.sql

prompt If 8i then run: @auth_connection_8i.sql



